summaryrefslogtreecommitdiffstats
path: root/drivers/gpu/drm/amd/amdgpu/amdgpu_vm.h
diff options
context:
space:
mode:
authorChristian König <christian.koenig@amd.com>2020-04-01 12:50:56 +0200
committerAlex Deucher <alexander.deucher@amd.com>2020-04-28 16:20:30 -0400
commiteaad0c3aa978e7ed654e574691b56cc24d2d409a (patch)
treee1205d9aee1e48626077bd1cbe914abb33dfafd6 /drivers/gpu/drm/amd/amdgpu/amdgpu_vm.h
parent9ecefb19c3a6626c27ea7ee72d431f22462e1d54 (diff)
downloadlinux-stable-eaad0c3aa978e7ed654e574691b56cc24d2d409a.tar.gz
linux-stable-eaad0c3aa978e7ed654e574691b56cc24d2d409a.tar.bz2
linux-stable-eaad0c3aa978e7ed654e574691b56cc24d2d409a.zip
drm/amdgpu: rename direct to immediate for VM updates
To avoid confusion with direct ring submissions rename bottom of pipe VM table changes to immediate updates. Signed-off-by: Christian König <christian.koenig@amd.com> Reviewed-by: Felix Kuehling <Felix.Kuehling@amd.com> Signed-off-by: Alex Deucher <alexander.deucher@amd.com>
Diffstat (limited to 'drivers/gpu/drm/amd/amdgpu/amdgpu_vm.h')
-rw-r--r--drivers/gpu/drm/amd/amdgpu/amdgpu_vm.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_vm.h b/drivers/gpu/drm/amd/amdgpu/amdgpu_vm.h
index fd61466dc226..2cb04b54ec58 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_vm.h
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_vm.h
@@ -206,9 +206,9 @@ struct amdgpu_vm_update_params {
struct amdgpu_vm *vm;
/**
* @direct: if changes should be made directly
*/
- bool direct;
+ bool immediate;
/**
* @pages_addr:
@@ -274,11 +274,11 @@ struct amdgpu_vm {
struct dma_fence *last_update;
/* Scheduler entities for page table updates */
- struct drm_sched_entity direct;
+ struct drm_sched_entity immediate;
struct drm_sched_entity delayed;
/* Last submission to the scheduler entities */
- struct dma_fence *last_direct;
+ struct dma_fence *last_immediate;
unsigned int pasid;
/* dedicated to vm */
@@ -379,7 +379,7 @@ int amdgpu_vm_validate_pt_bos(struct amdgpu_device *adev, struct amdgpu_vm *vm,
void *param);
int amdgpu_vm_flush(struct amdgpu_ring *ring, struct amdgpu_job *job, bool need_pipe_sync);
int amdgpu_vm_update_pdes(struct amdgpu_device *adev,
- struct amdgpu_vm *vm, bool direct);
+ struct amdgpu_vm *vm, bool immediate);
int amdgpu_vm_clear_freed(struct amdgpu_device *adev,
struct amdgpu_vm *vm,
struct dma_fence **fence);
@@ -206,9 +206,9 @@ struct amdgpu_vm_update_params {
struct amdgpu_vm *vm;
/**
- * @direct: if changes should be made directly
+ * @immediate: if changes should be made immediately
*/